function CalibratedParameterValues = GetCalibratedParameters(CalibratedParameterNames,ModelParameters)
% GetCalibratedParameters: Determines the values of the calibrated parameters and reports them in
%                          a vector.
%
% USAGE:
%
%       CalibratedParameterValues = GetCalibratedParameters(CalibratedParameterNames,ModelParameters)
%
% REQUIRED INPUT:  CalibratedParameterNames (string matrix) of dimension NumCalxCalNameLenght with the
%                                           names of the calibrated parameters.
%
%                  ModelParameters (structure) with fieldnames given by all the individual parameters
%                                           of the model and values equal to the parameter values.
%
% REQUIRED OUTPUT: CalibratedParameterValues (vector) of dimension NumCal x 1 with the values of the
%                                           calibrated parameters.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2024 European Central Bank.
%
%                       First version: March 26, 2019.
%                        This version: January 8, 2024.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 27-03-2019: Updated the documentation.
%
% * 08-01-2020: Updated the documentation.
%
% * 25-01-2021: Updated the documentation.
%
% * 04-01-2022: Updated the documentation.
%
% * 03-01-2023: Updated the documentation.
%
% * 08-01-2024: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
% initialize
%
NumCal = size(CalibratedParameterNames,1);
CalibratedParameterValues = zeros(NumCal,1);
for i=1:NumCal;
   CalibratedParameterValues(i) = getfield(ModelParameters,StringTrim(CalibratedParameterNames(i,:)));
end;

%
% end of GetCalibratedParameters.m
%
