function ModelParameters = UpdateFLMParameters(ModelParameters)
% UpdateFLMParameters: Shows how to define updated parameters from previously defined parameters
%
% USAGE:
%
%       ModelParameters = InitializeFLMParameters(ModelParameters)
%
% REQUIRED INPUT:  ModelParameters (structure) with fields corresponding to the parameters
%                                   you need for defining new parameters that should be
%                                   added to the structure.
%
% REQUIRED OUTPUT: ModelParameters (structure) with additions to the input structure.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2024 European Central Bank.
%
%                       First version: December 21, 2012.
%                        This version: January 15, 2024.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 02-01-2013: Updated the documentation.
%
% * 27-01-2014: Updated the documentation.
%
% * 13-01-2015: Updated the documentation.
%
% * 21-01-2016: Updated the documentation.
%
% * 10-02-2017: Updated the documentation.
%
% * 15-01-2018: Updated the documentation.
%
% * 21-01-2019: Updated the documentation.
%
% * 08-01-2020: Updated the documentation.
%
% * 25-01-2021: Updated the documentation.
%
% * 05-01-2022: Updated the documentation.
%
% * 04-01-2023: Updated the documentation.
%
% * 15-01-2024: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
% Updated parameters in Fagan, Lothian and McNelis (2012, JAE)
%

ModelParameters.phi1 = ((ModelParameters.sigma-1)*ModelParameters.h)/(1-(ModelParameters.beta*ModelParameters.h));
ModelParameters.phi2 = (ModelParameters.sigma+((ModelParameters.sigma-1)*ModelParameters.beta*ModelParameters.h^2)-(ModelParameters.beta*ModelParameters.h))/(1-(ModelParameters.beta*ModelParameters.h));
ModelParameters.gammaf = (ModelParameters.beta*ModelParameters.theta)/(ModelParameters.theta+(ModelParameters.omega*(1-(ModelParameters.theta*(1-ModelParameters.beta)))));
ModelParameters.gammab = (ModelParameters.omega)/(ModelParameters.theta+(ModelParameters.omega*(1-(ModelParameters.theta*(1-ModelParameters.beta)))));

%
% end of UpdateFLMParameters.m
%
