function BeliefSys = SloWoREStyleBeliefSystemFile(XVariableNames,StateVariableNames,ForwardVariableNames)
% SloWoREStyleBeliefSystemFile: Sets up an alternative belief system to the default system by following the
%                               logic of the RE solution (F matrix).
%
% USAGE:
%
%       BeliefSys = SloWoREStyleBeliefSystemFile(XVariableNames,StateVariableNames,ForwardVariableNames)
%
% REQUIRED INPUT:  XVariableNames (string matrix) of dimension k x k1 with the names of the deterministic
%                                 variables.
%
%                  StateVariableNames (string matrix) of dimension r x r1 with the names of all the state
%                                 variables.
%
%                  ForwardVariableNames (string matrix) of dimension f x f1 with the names of all the
%                                 forward looking variables.
%
% REQUIRED OUTPUT: BeliefSys (structure) with fields "m" an integer denoting the maximum number of lags
%                                 of the state variables in the belief equations; "Name" a string with the
%                                 name of the belief system; and G a cell array with f matrices, one for each
%                                 forward looking variable of dimension (k+r*m) x g_j where g_j is the number
%                                 of explanatory variables in the belief equation for forward looking variable
%                                 j. For the specification in the file "AnSchorfheideModel.aim", the forward
%                                 looking variables are yhat and pihat.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2024 European Central Bank.
%
%                       First version: April 14, 2020.
%                        This version: January 15, 2024.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 15-04-2020: Updated the documentation.
%
% * 25-01-2021: Updated the documentation.
%
% * 05-01-2022: Updated the documentation.
%
% * 04-01-2023: Updated the documentation.
%
% * 15-01-2024: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
% initialize
%
k = size(XVariableNames,1);
r = size(StateVariableNames,1);
f = size(ForwardVariableNames,1);
m = 1;
%
BeliefSys.m = m;
BeliefSys.Name = 'RE-Style-Beliefs';
%
% for this model f=2
%
G = cell(f,1);
G1 = zeros(k+(r*m),13);
%
% belief equation for c
%
% k=1
% r=28
% m=1
%
% the constant
%
G1(loc(XVariableNames,'const'),1) = 1;
%
% first lag of c, i, r, piy, k, w, ygap, epsg, epsb, epsi, epsa, epsr
%
G1(loc(StateVariableNames,'c')+k,2) = 1;
G1(loc(StateVariableNames,'i')+k,3) = 1;
G1(loc(StateVariableNames,'r')+k,4) = 1;
G1(loc(StateVariableNames,'piy')+k,5) = 1;
G1(loc(StateVariableNames,'k')+k,6) = 1;
G1(loc(StateVariableNames,'w')+k,7) = 1;
G1(loc(StateVariableNames,'ygap')+k,8) = 1;
G1(loc(StateVariableNames,'epsg')+k,9) = 1;
G1(loc(StateVariableNames,'epsb')+k,10) = 1;
G1(loc(StateVariableNames,'epsi')+k,11) = 1;
G1(loc(StateVariableNames,'epsa')+k,12) = 1;
G1(loc(StateVariableNames,'epsr')+k,13) = 1;
%
% belief equations for remaining forward looking variable: i, l, piy, q, rk, w
% they all have the same 12 first lagged variables and a constant.
%
G{1,1} = G1;
G{2,1} = G1;
G{3,1} = G1;
G{4,1} = G1;
G{5,1} = G1;
G{6,1} = G1;
G{7,1} = G1;
%
% complete the output structure
%
BeliefSys.G = G;

%
% end of SloWoREStyleBeliefSystemFile.m
%
