function WindowsVersion = GetWindowsVersion
% GetWindowsVersion: Returns the windows version as a number.
%
% USAGE:
%
%       WindowsVersion = GetWindowsVersion
%
% REQUIRED OUTPUT: WindowsVersion (scalar) with the version number with 1 decimal.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2023 European Central Bank.
%
%                       First version: February 10, 2021.
%                        This version: January 6, 2023.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 18-02-2021: Updated the documentation.
%
% * 05-01-2022: Updated the documentation.
%
% * 06-01-2023: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

WindowsVersion = [];
[status,WinVers] = system('ver');
pos = 0;
n = length(WinVers);
for i=1:9;
   pos = strfind(WinVers,int2str(i));
   if isempty(pos)==0;
      pos = pos(1);
      WinVers = WinVers(pos:n);
      pos2 = strfind(WinVers,'.');
      WindowsVersion = str2num(WinVers(1:pos2(1)+1));
      break;
   end;
end;


%
% end of GetWindowsVersion.m
%
