function [xparam1,hh,gg,fval,igg,jit,fcount,fdiff,abort,OptResults,ScreenMessages,phiEstimates,retcode] = YADAnewrat(func0,x,hh,gg,igg,ftol0,nit,flagg,ParamLUB,PriorStd,waitbar,ShowClock,waitbartext,CurrINI,varargin)
%  [xparam1,hh,gg,fval,igg,jit,fcount,fdiff,abort,OptResults,ScreenMessages,phiEstimates,retcode] = YADAnewrat(func0,x,hh,gg,igg,ftol0,nit,flagg,ParamLUB,PriorStd,waitbar,ShowClock,waitbartext,CurrINI,varargin)
%
%  Optimiser with outer product gradient and with sequences of univariate steps
%  uses Chris Sims subroutine for line search
%
%  func0 = name of the function
%  there must be a version of the function called [func0,'_hh.m'], that also
%  gives as second OUTPUT the single contributions at times t=1,...,T
%    of the log-likelihood to compute outer product gradient
%
%  x = starting guess
%  hh = initial Hessian [OPTIONAL]
%  gg = initial gradient [OPTIONAL]
%  igg = initial inverse Hessian [OPTIONAL]
%  ftol0 = ending criterion for function change 
%  nit = maximum number of iterations
%
%  In each iteration, Hessian is computed with outer product gradient.
%  for final Hessian (to start Metropolis):
%  flagg = 0, final Hessian computed with outer product gradient
%  flagg = 1, final 'mixed' Hessian: diagonal elements computed with numerical second order derivatives
%             with correlation structure as from outer product gradient, 
%  flagg = 2, full numerical Hessian
%
%  varargin = list of parameters for func0 

% Copyright (C) 2004-2011 Dynare Team
%
% This file is part of Dynare.
%
% Dynare is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% Dynare is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% This version has been prepared for YADA by Anders Warne.
%
% First version: 07-07-2011
% Last modified: 14-08-2023
%

%global bayestopt_
icount=0;
nx=length(x);
xparam1=x;
%ftol0=1.e-6;
htol_base = max(1.e-5, ftol0);
flagit=0;  % mode of computation of hessian in each iteration
ftol=ftol0;
gtol=1.e-3;
htol=htol_base;
htol0=htol_base;
%gibbstol=length(bayestopt_.pshape)/50; %25;
gibbstol=nx/50;
%func_hh = [func0,'_hh'];
func_hh = [func0,'4Time'];
%func = str2func(func0);
func = func0;
fval0 = feval(func,x,varargin{:});
fval=fval0;
% initialize mr_gstep and mr_hessian
% mr_gstep(1,x);
%mr_hessian(1,x);
%
htol = 1.e-4;
h1=(1e-6)*ones(nx,1);
%
abort = '';
OptResults = [];
phiEstimates = [];
ContinueOptim = 0;
fdiff = NaN;
fcount = 0;
retcode = [];
%
ScreenMessages = 'Initializing...';
%
if isempty(hh)
   %[dum, gg, htol0, igg, hhg, h1] = mr_hessian(0,x,func_hh,flagit,htol,varargin{:});
   [dum, gg, htol0, igg, hhg, h1] = YADAMRHessian(x,func_hh,flagit,htol,h1,htol,ParamLUB,PriorStd,varargin{:});
   hh0 = reshape(dum,nx,nx);
   hh=hhg;
   if min(eig(hh0))<0,
      hh0=hhg; %generalized_cholesky(hh0);
   elseif flagit==2,
      hh=hh0;
      igg=inv(hh);
   end
   if htol0>htol,
      htol=htol0;
      %ftol=htol0;
   end
else
   hh0=hh;
   hhg=hh;
   igg=inv(hh);
   try;
      [gg, badg] = YADAnumgrad(func0,xparam1,varargin{:});
   catch;
      [gg, badg] = YADANumGradient(func0,xparam1,varargin{:});
   end;
end
H = igg;
%disp(['Gradient norm ',num2str(norm(gg))])
ScreenMessages = strvcat(ScreenMessages,['Gradient norm ',num2str(norm(gg))]);
ee=eig(hh);
%disp(['Minimum Hessian eigenvalue ',num2str(min(ee))])
%disp(['Maximum Hessian eigenvalue ',num2str(max(ee))])
ScreenMessages = strvcat(ScreenMessages,['Minimum Hessian eigenvalue ',num2str(min(ee))],['Maximum Hessian eigenvalue ',num2str(max(ee))]);
g=gg;
check=0;
%if max(eig(hh))<0, disp('Negative definite Hessian! Local maximum!'), pause, end,
if max(eig(hh))<0;
   ScreenMessages = strvcat(ScreenMessages,'Negative definite Hessian! Local maximum!');
end;
%save m1.mat x hh g hhg igg fval0
%
%
% setup a progress dialog if asked to
%
if waitbar==1;
   ProgressStructure.title = ['Progress for ' num2str(nit,'%0.0f') ' iterations'];
   ProgressStructure.facecolor = CurrINI.progress_facecolor;
   ProgressStructure.startfacecolor = CurrINI.progress_startfacecolor;
   ProgressStructure.edgecolor = CurrINI.progress_edgecolor;
   ProgressStructure.bgcolor = CurrINI.progress_bgcolor;
   ProgressStructure.stop = 0;
   ProgressStructure.clock = ShowClock;
   ProgressStructure.label = 'Convergence Value:';
   %
   if strcmp(StringTrim(waitbartext),'')==0;
      ProgressStructure.name = waitbartext;
   else;
      ProgressStructure.name = 'Numerical Optimization with newrat';
   end;
   ProgressStructure.CurrINI = CurrINI;
   mywait = ProgressDLG(0,ProgressStructure);
   set(mywait,'Color',get(CurrINI.GraphicsRoot,'defaultuicontrolbackgroundcolor'));
   drawnow;
else;
   %
   % show a wait dialog
   %
   txt = ['Please wait while YADA attempts to estimate the posterior mode with newrat. A maximum of ' int2str(nit) ' iterations is used.'];
   WaitHandle = WaitDLG(txt,'information','Numerical Optimization with newrat',500,200,CurrINI,0);
   WaitControls = get(WaitHandle,'UserData');
end;
%
igrad=1;
igibbs=1;
inx=eye(nx);
jit=0;
nig=[];
ig=ones(nx,1);
ggx=zeros(nx,1);
while norm(gg)>gtol & check==0 & jit<nit,
   jit=jit+1;
   tic;
   icount=icount+1;
   if waitbar==1;
      abort = get(mywait,'UserData');
      if (strcmp(abort,'cancel')==1)|(strcmp(abort,'done')==1);
         break;
      else;
         if jit<=nit;
            ProgressDLG([jit/nit fdiff]);
         end;
      end;
   end;
   %bayestopt_.penalty = fval0(icount);
   penalty = fval0(icount);
%   disp([' '])
%   disp(['Iteration ',num2str(icount)])
   %[fval x0 fc retcode] = csminit(func0,xparam1,fval0(icount),gg,0,H,varargin{:});
   [fval,x0,fc,retcode,ScreenMessage,ContinueOptim] = YADAcsminit(func0,xparam1,fval0(icount),gg,0,H,nit,ContinueOptim,'Newrat',CurrINI,varargin{:});
   ScreenMessages = strvcat(ScreenMessages,' ',['Iteration no: ' int2str(jit)],ScreenMessage);
   fcount = fcount+fc;
   if (igrad==1)&(ContinueOptim~=-1),
      %[fval1 x01 fc retcode1] = csminit(func0,x0,fval,gg,0,inx,varargin{:});
      try;
         [fval1,x01,fc,retcode,ScreenMessage,ContinueOptim] = YADAcsminit(func0,x0,fval,gg,0,inx,nit,ContinueOptim,'Newrat',CurrINI,varargin{:});
         ScreenMessages = strvcat(ScreenMessages,ScreenMessage);
         fcount = fcount+fc;
         if (fval-fval1)>1, %(fval0(icount)-fval),
%            disp('Gradient step!!')
            ScreenMessages = strvcat(ScreenMessages,'Gradient step!!');
         else
            igrad=0;
         end
         fval=fval1;
         x0=x01;
      catch;
         igrad=0;
      end;
   end
   if (fval0(icount)-fval)<1.e-2*(gg'*(H*gg))/2 & igibbs & ContinueOptim~=-1,
      if length(find(ig))<nx,
         ggx=ggx*0;
         ggx(find(ig))=gg(find(ig));
         hhx = reshape(dum,nx,nx);
         iggx=eye(length(gg));
         iggx(find(ig),find(ig)) = inv( hhx(find(ig),find(ig)) );
         %[fvala x0 fc retcode] = csminit(func0,x0,fval,ggx,0,iggx,varargin{:});
         [fvala,x0,fc,retcode,ScreenMessage,ContinueOptim] = YADAcsminit(func0,x0,fval,ggx,0,iggx,nit,ContinueOptim,'Newrat',CurrINI,varargin{:});
         ScreenMessages = strvcat(ScreenMessages,ScreenMessage);
         fcount = fcount+fc;
      end
      %[fvala, x0, ig] = mr_gstep(h1,x0,func0,htol,varargin{:});
      [fvala,x0,ig,fc,ScreenMessage,ContinueOptim] = YADAMRGstep(h1,x0,func0,htol,nit,ContinueOptim,CurrINI,varargin{:});
      ScreenMessages = strvcat(ScreenMessages,ScreenMessage);
      fcount = fcount+fc;
      % if length(find(ig))==0,
         %[fvala, x0, ig] = mr_gstep(h1,x0,func0,htol/10,varargin{:});
      % end
      nig=[nig ig];
%      disp('Sequence of univariate steps!!')
      ScreenMessages = strvcat(ScreenMessages,'Sequence of univariate steps!!');
      fval=fvala;
   end
   if (fval0(icount)-fval)<ftol & flagit==0 & ContinueOptim~=-1,
%      disp('Try diagonal Hessian')
      ihh=diag(1./(diag(hhg)));        
      %[fval2 x0 fc retcode2] = csminit(func2str(func),x0,fval,gg,0,ihh,varargin{:});
      [fval2,x0,fc,retcode,ScreenMessage,ContinueOptim] = YADAcsminit(func,x0,fval,gg,0,ihh,nit,ContinueOptim,'Newrat',CurrINI,varargin{:});
      ScreenMessages = strvcat(ScreenMessages,ScreenMessage);
      fcount = fcount+fc;
      if (fval-fval2)>=ftol ,
         %hh=diag(diag(hh));
%         disp('Diagonal Hessian successful')        
         ScreenMessages = strvcat(ScreenMessages,'Diagonal Hessian successful');    
      end
      fval=fval2;
   end        
   if (fval0(icount)-fval)<ftol & flagit==0 & ContinueOptim~=-1,
%      disp('Try gradient direction')
      ScreenMessages = strvcat(ScreenMessages,'Try gradient direction');
      ihh0=inx.*1.e-4;        
      %[fval3 x0 fc retcode3] = csminit(func2str(func),x0,fval,gg,0,ihh0,varargin{:});
      [fval3,x0,fc,retcode,ScreenMessage,ContinueOptim] = YADAcsminit(func,x0,fval,gg,0,ihh0,nit,ContinueOptim,'Newrat',CurrINI,varargin{:});
      ScreenMessages = strvcat(ScreenMessages,ScreenMessage);
      fcount = fcount+fc;
      if (fval-fval3)>=ftol ,
         %hh=hh0;
         %ihh=ihh0;
%         disp('Gradient direction successful')      
         ScreenMessages = strvcat(ScreenMessages,'Gradient direction successful');      
      end
      fval=fval3;
   end        
   xparam1=x0;
   x(:,icount+1)=xparam1;
   fval0(icount+1)=fval;
   if (fval0(icount)-fval)<ftol,
%      disp('No further improvement is possible!')
      ScreenMessages = strvcat(ScreenMessages,'No further improvement is possible!');
      check=1;
      if flagit==2,
         hh=hh0;
      elseif flagg>0,
         %[dum, gg, htol0, igg, hhg,h1] = mr_hessian(0,xparam1,func_hh,flagg,ftol0,varargin{:});  
         [dum, gg, htol0, igg, hhg,h1] = YADAMRHessian(xparam1,func_hh,flagg,ftol0,h1,htol,ParamLUB,PriorStd,varargin{:});   
         if flagg==2,
            hh = reshape(dum,nx,nx);
            ee=eig(hh);
            if min(ee)<0
               hh=hhg;
            end
         else
            hh=hhg;
         end
      end
%      disp(['Actual dxnorm ',num2str(norm(x(:,end)-x(:,end-1)))])
%      disp(['FVAL          ',num2str(fval)])
%      disp(['Improvement   ',num2str(fval0(icount)-fval)])
%      disp(['Ftol          ',num2str(ftol)])
%      disp(['Htol          ',num2str(htol0)])
%      disp(['Gradient norm  ',num2str(norm(gg))])
      ee=eig(hh);
%      disp(['Minimum Hessian eigenvalue ',num2str(min(ee))])
%      disp(['Maximum Hessian eigenvalue ',num2str(max(ee))])
      ScreenMessages = strvcat(ScreenMessages,['Actual dxnorm ',num2str(norm(x(:,end)-x(:,end-1)))],['FVAL          ',num2str(fval)],['Improvement   ',num2str(fval0(icount)-fval)],['Ftol          ',num2str(ftol)],['Htol          ',num2str(htol0)]);
      ScreenMessages = strvcat(ScreenMessages,['Gradient norm  ',num2str(norm(gg))],['Minimum Hessian eigenvalue ',num2str(min(ee))],['Maximum Hessian eigenvalue ',num2str(max(ee))]);
      g(:,icount+1)=gg;
   else
      df = fval0(icount)-fval;
%      disp(['Actual dxnorm ',num2str(norm(x(:,end)-x(:,end-1)))])
%      disp(['FVAL          ',num2str(fval)])
%      disp(['Improvement   ',num2str(df)])
%      disp(['Ftol          ',num2str(ftol)])
%      disp(['Htol          ',num2str(htol0)])
      ScreenMessages = strvcat(ScreenMessages,['Actual dxnorm ',num2str(norm(x(:,end)-x(:,end-1)))],['FVAL          ',num2str(fval)],['Improvement   ',num2str(df)],['Ftol          ',num2str(ftol)],['Htol          ',num2str(htol0)]);
%      if df<htol0,
%         htol=max(htol_base,df/10);
%      end
      htol=htol_base;
      if norm(x(:,icount)-xparam1)>1.e-12,
%        try 
%           save m1.mat x fval0 nig -append
%        catch
%           save m1.mat x fval0 nig 
%        end
         %[dum, gg, htol0, igg, hhg, h1] = mr_hessian(0,xparam1,func_hh,flagit,htol,varargin{:});
         [dum, gg, htol0, igg, hhg, h1] = YADAMRHessian(xparam1,func_hh,flagit,htol,h1,htol,ParamLUB,PriorStd,varargin{:});
         if htol0>htol, %ftol,
            %ftol=htol0;
            htol=htol0;
%            disp(' ')
%            disp('Numerical noise in the likelihood')
%            disp('Tolerance has to be relaxed')
%            disp(' ')
            ScreenMessages = strvcat(ScreenMessages,' ','Numerical noise in the likelihood','Tolerance has to be relaxed',' ');
         %elseif htol0<ftol,
         %   ftol=max(htol0, ftol0);
         end
         hh0 = reshape(dum,nx,nx);
         hh=hhg;
         if flagit==2,
            if min(eig(hh0))<=0,
               hh0=hhg; %generalized_cholesky(hh0);
            else 
               hh=hh0;
               igg=inv(hh);
             end
         end
      end
%      disp(['Gradient norm  ',num2str(norm(gg))])
      ee=eig(hh);
%      disp(['Minimum Hessian eigenvalue ',num2str(min(ee))])
%      disp(['Maximum Hessian eigenvalue ',num2str(max(ee))])
      ScreenMessages = strvcat(ScreenMessages,['Gradient norm  ',num2str(norm(gg))],['Minimum Hessian eigenvalue ',num2str(min(ee))],['Maximum Hessian eigenvalue ',num2str(max(ee))]);
%      if max(eig(hh))<0, disp('Negative definite Hessian! Local maximum!'), pause, end,
      if max(eig(hh))<0;
         ScreenMessages = strvcat(ScreenMessages,'Negative definite Hessian! Local maximum!');
      end;
      t=toc;
%      disp(['Elapsed time for iteration ',num2str(t),' s.'])
      ScreenMessages = strvcat(ScreenMessages,['Elapsed time for iteration ',num2str(t),' s.']);
      g(:,icount+1)=gg;
%      H = bfgsi(H,g(:,end)-g(:,end-1),x(:,end)-x(:,end-1));
      H = igg;
%      save m1.mat x hh g hhg igg fval0 nig H
   end
   %
   % collect results
   %
   fdiff = fval0(icount)-fval;
   OptResults = [OptResults;[jit -fval fdiff max(abs(gg))]];
   phiEstimates = [phiEstimates xparam1];
   %
   % check if user has selected to abandon optimization
   %
   if ContinueOptim==-1;
      break;
   end;
end

%save m1.mat x hh g hhg igg fval0 nig
if ftol>ftol0,
%   disp(' ')
%   disp('Numerical noise in the likelihood')
%   disp('Tolerance had to be relaxed')
%   disp(' ')
   ScreenMessages = strvcat(ScreenMessages,'Numerical noise in the likelihood. Tolerance had to be relaxed');
end

if (jit==nit)&(check==0),
%   disp(' ')
%   disp('Maximum number of iterations reached')
%   disp(' ')
   jit=nit+1;
   ScreenMessages = strvcat(ScreenMessages,'Maximum number of iterations reached');
end

if norm(gg)<=gtol,
%   disp(['Estimation ended:'])
%   disp(['Gradient norm < ', num2str(gtol)])
   ScreenMessages = strvcat(ScreenMessages,'Estimation ended:',['Gradient norm < ', num2str(gtol)]);
end
if check==1,
%   disp(['Estimation successful.'])
   ScreenMessages = strvcat(ScreenMessages,'Estimation successful.');
end
%
% close waitbars and the like
%
if waitbar==1;
   if IsHandle(mywait)==1;
      set(mywait,'UserData','done');
      close(mywait);
      drawnow;
      pause(0.02);
   end;
else;
   if IsHandle(WaitHandle)==1;
      set(WaitControls.text,'UserData','done');
      delete(WaitHandle);
      drawnow;
      pause(0.02);
   end;
end;

%return
%  
%function f00 = lsearch(lam,func,x,dx,varargin)
%
%x0=x-dx*lam;
%f00=feval(func,x0,varargin{:});

%
% end of YADAnewrat.m
%
