function controls = ProjectMenu(maingui,controls)
% ProjectMenu: Sets up the project menu example.
%
% USAGE:
%
%       controls = ProjectMenu(maingui,controls)
%
% REQUIRED INPUT:  maingui (handle) to the main dialog window of YADA.
%
%                  controls (structure) with handles to the controls on the YADA gui.
%
% REQUIRED OUTPUT: controls (structure) with handles to the controls on the YADA gui.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2024 European Central Bank.
%
%                       First version: June 9, 2009.
%                        This version: January 19, 2024.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 12-06-2009: Updated the documentation.
%
% * 05-01-2010: Updated the documentation.
%
% * 05-01-2011: Updated the documentation.
%
% * 05-01-2012: Updated the documentation.
%
% * 03-01-2013: Updated the documentation.
%
% * 27-01-2014: Updated the documentation.
%
% * 13-01-2015: Updated the documentation.
%
% * 22-02-2016: Updated the documentation.
%
% * 22-03-2017: Updated the documentation.
%
% * 14-05-2018: Updated the documentation.
%
% * 24-01-2019: Updated the documentation.
%
% * 26-01-2021: Updated the documentation.
%
% * 06-01-2022: Updated the documentation.
%
% * 06-01-2023: Updated the documentation.
%
% * 19-01-2024: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
% handle to the project menu
%
controls.projectmenu = uimenu('Parent',maingui, ...
   'Label','&Project', ...
   'Tag','ProjectMenu');
%
% spatial distortions
%
controls.project.spatdist.parent = uimenu('Parent',controls.projectmenu, ...
   'Label','&Spatial Distortions', ...
   'Tag','SpatialDistortionsMenuParent');
%
% handle to initial parameter values for spatial distortions tool
%
controls.project.spatdist.initialvalues = uimenu('Parent',controls.project.spatdist.parent, ...
   'Label','&Initial Values...', ...
   'Enable','off', ...
   'Callback','ProjectFunctions spatdist_init_values', ...
   'Tag','SpatialDistortionsMenuInitialValue');
%
% handle to prior distribution for spatial distortions tool
%
controls.project.spatdist.prior = uimenu('Parent',controls.project.spatdist.parent, ...
   'Label','P&rior Distribution...', ...
   'Enable','off', ...
   'Callback','ProjectFunctions spatdist_prior_dist', ...
   'Tag','SpatialDistortionsMenuPrior');
%
% handle to posterior mode values for spatial distortions tool
%
controls.project.spatdist.postmode = uimenu('Parent',controls.project.spatdist.parent, ...
   'Label','&Posterior Mode...', ...
   'Enable','off', ...
   'Separator','on', ...
   'Callback','ProjectFunctions spatdist_post_mode', ...
   'Tag','SpatialDistortionsMenuPosteriorMode');
%
% handle to posterior distribution for spatial distortions tool
%
controls.project.spatdist.posterior = uimenu('Parent',controls.project.spatdist.parent, ...
   'Label','Posterior &Distribution...', ...
   'Enable','off', ...
   'Callback','ProjectFunctions spatdist_post_dist', ...
   'Tag','SpatialDistortionsMenuPosterior');

%
% end of ProjectMenu.m
%
